@@ -930,6 +930,38 @@ class Radio:
         else:
             self.pb.ClearField('wifi_mode')
 
+    @property
+    def max_cpe_radios(self):
+        return self.pb.max_cpe_radios if self.pb.HasField('max_cpe_radios') else None
+
+    @max_cpe_radios.setter
+    def max_cpe_radios(self, value):
+        if value is None:
+            self.pb.ClearField('max_cpe_radios')
+        elif value >= 0 and int.bit_length(value) < 32:
+            self.pb.max_cpe_radios = value
+        elif self.errctx:
+            self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                            'Invalid value for NetworkElement.Radio.max_cpe_radios',
+                            value=value,
+                            metric_name='NetworkElement.Radio.max_cpe_radios')
+
+    @property
+    def max_distance(self):
+        return self.pb.max_distance if self.pb.HasField('max_distance') else None
+
+    @max_distance.setter
+    def max_distance(self, value):
+        if value is None:
+            self.pb.ClearField('max_distance')
+        elif value >= 0 and int.bit_length(value) < 32:
+            self.pb.max_distance = value
+        elif self.errctx:
+            self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                            'Invalid value for NetworkElement.Radio.max_distance',
+                            value=value,
+                            metric_name='NetworkElement.Radio.max_distance')
+
 
 class Sector:
 
@@ -2127,6 +2159,17 @@ class NetworkElement:
         if value is not None:
             self.pb.status = value
 
+    @property
+    def imsi(self):
+        return self.pb.imsi if self.pb.HasField('imsi') else None
+
+    @imsi.setter
+    def imsi(self, value):
+        if value is None:
+            self.pb.ClearField('imsi')
+        else:
+            self.pb.imsi = value
+
 
 class NetworkElementUpdate:
 
@@ -2251,6 +2294,22 @@ class NetworkElementUpdate:
         if value is not None:
             self.pb.data.CopyFrom(value.pb)
 
+    @property
+    def poll_time(self):
+        return self.pb.poll_time if self.pb.HasField('poll_time') else None
+
+    @poll_time.setter
+    def poll_time(self, value):
+        if value is None:
+            self.pb.ClearField('poll_time')
+        elif value >= 0 and int.bit_length(value) < 32:
+            self.pb.poll_time = value
+        elif self.errctx:
+            self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                            'Invalid value for NetworkElementUpdate.poll_time',
+                            value=value,
+                            metric_name='NetworkElementUpdate.poll_time')
+
 
 class NetworkElementDiscovery:
 
